# Python CCY

[![PyPI version](https://badge.fury.io/py/ccy.svg)](https://badge.fury.io/py/ccy)
[![Python versions](https://img.shields.io/pypi/pyversions/ccy.svg)](https://pypi.org/project/ccy)
[![Python downloads](https://img.shields.io/pypi/dd/ccy.svg)](https://pypi.org/project/ccy)
[![build](https://github.com/quantmind/ccy/actions/workflows/build.yml/badge.svg)](https://github.com/quantmind/ccy/actions/workflows/build.yml)
[![codecov](https://codecov.io/gh/quantmind/ccy/branch/main/graph/badge.svg?token=2L5SY0WkXv)](https://codecov.io/gh/quantmind/ccy)

A python module for currencies. The module compiles a dictionary of
currency objects containing information useful in financial analysis.
Not all currencies in the world are supported yet. You are welcome to
join and add more.

* Documentation is available as [ccy jupyter book](https://quantmind.github.io/ccy/).
* Install the command line tool with `pip install ccy[cli]`.
* Show all currencies in the command line via `ccys show`
* Trading centres are available when installing the `holidays` extra via
  ```
  pip install ccy[holidays]
  ```
